@@ -51,7 +51,7 @@ FILE *in_file;
 typedef long DWORD;
 
 /* in/out macros */
-#include <asm/io.h>
+//#include <asm/io.h>
 #define _inp(a) inb(a)
 #define _outp(a,d) outb(d,a)
 
